@@ -33,7 +33,7 @@ ContactsWindow::ContactsWindow(QWidget *parent, Group* group) :
     m_Timer = NULL;
 
 #ifdef Q_OS_SYMBIAN
-    QAction* softKey = new QAction( tr("Indietro"), this );
+    QAction* softKey = new QAction( tr("Back"), this );
     softKey->setSoftKeyRole( QAction::NegativeSoftKey );
     connect(softKey, SIGNAL(triggered()), this, SLOT(reject()));
     addAction(softKey);
@@ -151,7 +151,7 @@ void ContactsWindow::CercaSlot()
         }
     }
 
-    setWindowTitle(tr("GroupSMS - Rubrica (%1)").arg(count));
+    setWindowTitle(tr("Address book (%1)").arg(count));
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
