@@ -78,7 +78,6 @@ void GroupActionsWindow::PopulateContactsTable()
             QLabel* lbl = new QLabel(this);
             lbl->setAlignment(Qt::AlignCenter);
             lbl->setMaximumWidth(48);
-            //lbl->setMaximumSize(48, 48);
             if (c->Thumbnail != NULL)
                 lbl->setPixmap(QPixmap::fromImage(*c->Thumbnail).scaled(48, 48, Qt::KeepAspectRatio));
             else{
@@ -145,11 +144,12 @@ void GroupActionsWindow::SendSlot()
 {
     QList<QString> toSend = GetSelectedNumbers();
     if (toSend.count() > 0){
-        if (CommonStatic::ConfirmMessage(this,
+        /*if (CommonStatic::ConfirmMessage(this,
                                          tr("Confirm send"),
                                          QString(tr("Send %1 SMS to contacts from group %2?"))
                                          .arg(toSend.count())
                                          .arg(m_Group->Name)) == QMessageBox::Yes){
+        */
 #ifdef Q_WS_MAEMO_5
             QString strTo;
             foreach (QString n, toSend){
@@ -162,7 +162,7 @@ void GroupActionsWindow::SendSlot()
             smsUrl.addQueryItem("body", "");
             hildon_uri_open(smsUrl.toString().toStdString().c_str(),NULL,NULL);
 #endif
-        }
+        //}
     }
 }
 
